Method: Pantry::CommandLine#triggered_command

Defined in:
lib/pantry/command_line.rb

#triggered_commandObject

Returns details of the command found during parsing. Returns a hash with the keys banner and class, or returns nil if no matching command was found



59
60
61
62
63
64
# File 'lib/pantry/command_line.rb', line 59

def triggered_command
  [
    @commands[@parsed_options.command_found],
    @parsed_options[@parsed_options.command_found]
  ]
end